Module blaxel.core.client.models.mcp_definition_form
====================================================

Classes
-------

`MCPDefinitionForm()`
:   Form of the artifact
    
    Method generated by attrs for class MCPDefinitionForm.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :